@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 56555 2008-10-28 20:31:28Z CJP $"
-__revision__ = "$Revision: 56555 $"
+__svnid__ = "$Id: Editra.py 56856 2008-11-20 02:52:21Z CJP $"
+__revision__ = "$Revision: 56856 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -27,6 +27,7 @@ import base64
 import locale
 import time
 import getopt
+import shutil
 import wx
 
 # The event handler mixin is now part of wxPython proper, but there hasn't
@@ -90,43 +91,14 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         wx.App.__init__(self, *args, **kargs)
         events.AppEventHandlerMixin.__init__(self)
 
+        self.SetAppName(ed_glob.PROG_NAME)
+
         # Attributes
+        self.profile_updated = InitConfig()
         self._log = dev_tool.DEBUGP
         self._lock = False
         self._windows = dict()
 
-        # Setup Plugins after locale as they may have resource that need to
-        # be loaded.
-        self._pluginmgr = plugin.PluginManager()
-
-        self._log("[app][info] Registering Editra's ArtProvider")
-        wx.ArtProvider.PushProvider(ed_art.EditraArt())
-
-    def AddMessageCatalog(self, name, path):
-        """Add a catalog lookup path to the app
-        @param name: name of catalog (i.e 'projects')
-        @param path: catalog lookup path
-
-        """
-        if self.locale is not None:
-            path = resource_filename(path, 'locale')
-            self.locale.AddCatalogLookupPathPrefix(path)
-            self.locale.AddCatalog(name)
-
-    def OnInit(self):
-        """Initialize the Editor
-        @note: this gets called before __init__
-        @postcondition: custom artprovider and plugins are loaded
-
-        """
-        self.SetAppName(ed_glob.PROG_NAME)
-
-        self._log = dev_tool.DEBUGP
-        self._log("[app][info] Editra is Initializing")
-
-        self._isfirst = False # Is the first instance
-        self._instance = None
-
         if ed_glob.SINGLE:
             # Setup the instance checker
             instance_name = u"%s-%s" % (self.GetAppName(), wx.GetUserId())
@@ -168,6 +140,36 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         else:
             self._isfirst = True
 
+        # Setup Plugins after locale as they may have resource that need to
+        # be loaded.
+        self._pluginmgr = plugin.PluginManager()
+
+        self._log("[app][info] Registering Editra's ArtProvider")
+        wx.ArtProvider.PushProvider(ed_art.EditraArt())
+
+    def AddMessageCatalog(self, name, path):
+        """Add a catalog lookup path to the app
+        @param name: name of catalog (i.e 'projects')
+        @param path: catalog lookup path
+
+        """
+        if self.locale is not None:
+            path = resource_filename(path, 'locale')
+            self.locale.AddCatalogLookupPathPrefix(path)
+            self.locale.AddCatalog(name)
+
+    def OnInit(self):
+        """Initialize the Editor
+        @note: this gets called before __init__
+        @postcondition: custom artprovider and plugins are loaded
+
+        """
+        self._log = dev_tool.DEBUGP
+        self._log("[app][info] Editra is Initializing")
+
+        self._isfirst = False # Is the first instance
+        self._instance = None
+
         # Setup Locale
         locale.setlocale(locale.LC_ALL, '')
         self.locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
@@ -315,6 +317,13 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         return self._pluginmgr
 
+    def GetProfileUpdated(self):
+        """Was the profile updated 
+        @return: bool
+
+        """
+        return self.profile_updated
+
     def GetWindowInstance(self, wintype):
         """Get an instance of an open window if one exists
         @param wintype: Class type of window to look for
@@ -603,6 +612,7 @@ def InitConfig():
         ed_glob.CONFIG['PROFILE_DIR'] = os.path.join(config_base, u"profiles")
         ed_glob.CONFIG['PROFILE_DIR'] += os.sep
     else:
+        config_base = wx.StandardPaths.Get().GetUserDataDir()
         ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir("profiles")
 
     # Check for if config directory exists and if profile is from the current
@@ -632,6 +642,10 @@ def InitConfig():
             # Print modes don't use strings anymore
             if isinstance(profiler.Profile_Get('PRINT_MODE'), basestring):
                 profiler.Profile_Set('PRINT_MODE', ed_glob.PRINT_BLACK_WHITE)
+
+            # Simplifications to eol mode persistance (0.4.0)
+            TranslateEOLMode()
+
             #---- End Temporary Profile Adaptions ----#
 
             # Write out updated profile
@@ -648,9 +662,32 @@ def InitConfig():
         # Fresh install
         util.CreateConfigDir()
 
+        # Check and upgrade installs from old location
+        success = True
+        try:
+            success = UpgradeOldInstall()
+        except Exception, msg:
+            dev_tool.DEBUGP("[InitConfig][err] %s" % msg)
+            success = False
+
+        if not success:
+            old_cdir = u"%s%s.%s%s" % (wx.GetHomeDir(), os.sep,
+                                       ed_glob.PROG_NAME, os.sep)
+            msg = ("Failed to upgrade your old installation\n"
+                   "To retain your old settings you may need to copy some files:\n"
+                   "\nFrom: %s\n\nTo: %s") % (old_cdir, config_base)
+            wx.MessageBox(msg, "Upgrade Failed", style=wx.ICON_WARNING|wx.OK)
+
         # Set default eol for windows
         if wx.Platform == '__WXMSW__':
-            profiler.Profile_Set('EOL', 'Windows (\\r\\n)')
+            profiler.Profile_Set('EOL', 'CRLF')
+            profiler.Profile_Set('ICONSZ', (16, 16))
+
+    #---- Profile Loaded / Installed ----#
+
+    # Extra Adaption checks
+    TranslateEOLMode()
+    # End Extra Adaptions
 
     # Set debug mode
     if 'DEBUG' in profiler.Profile_Get('MODE'):
@@ -660,22 +697,90 @@ def InitConfig():
     ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
     ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir("pixmaps", True)
     ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir("plugins")
-    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps",
-                                                                    "theme"))
+    ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps", "theme"))
     ed_glob.CONFIG['LANG_DIR'] = util.ResolvConfigDir("locale", True)
     ed_glob.CONFIG['STYLES_DIR'] = util.ResolvConfigDir("styles")
     ed_glob.CONFIG['SYS_PLUGIN_DIR'] = util.ResolvConfigDir("plugins", True)
     ed_glob.CONFIG['SYS_STYLES_DIR'] = util.ResolvConfigDir("styles", True)
-    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join("tests",
-                                                                   "syntax"),
-                                                                   True)
-    if not util.HasConfigDir("cache"):
-        util.MakeConfigDir("cache")
+    ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join("tests", "syntax"), True)
+
+    # Make sure all standard config directories are there
+    for cfg in ["cache", "styles", "plugins", "profiles"]:
+        if not util.HasConfigDir(cfg):
+            util.MakeConfigDir(cfg)
     ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir("cache")
 
     return profile_updated
 
 #--------------------------------------------------------------------------#
+
+def UpgradeOldInstall():
+    """Upgrade an old installation and transfer all files if they exist
+    @note: FOR INTERNAL USE ONLY
+    @return: bool (True if success, False if failure)
+
+    """
+    old_cdir = u"%s%s.%s%s" % (wx.GetHomeDir(), os.sep,
+                               ed_glob.PROG_NAME, os.sep)
+    base = ed_glob.CONFIG['CONFIG_BASE']
+    if base is None:
+        base = wx.StandardPaths.Get().GetUserDataDir() + os.sep
+
+    err = 0
+    if os.path.exists(old_cdir) and \
+       base.lower().rstrip(os.sep) != old_cdir.lower().rstrip(os.sep):
+        for item in os.listdir(old_cdir):
+            print item
+            try:
+                dest = os.path.join(base, item)
+                item = os.path.join(old_cdir, item)
+                if os.path.exists(dest):
+                    if os.path.isdir(dest):
+                        shutil.rmtree(dest, True)
+                    else:
+                        os.remove(dest)
+
+                shutil.move(item, dest)
+            except Exception, msg:
+                util.Log("[Upgrade][err] %s" % msg)
+                err += 1
+                continue
+
+        os.rmdir(old_cdir)
+
+        # Load the copied over profile
+        pstr = profiler.GetProfileStr()
+        prof = os.path.basename(pstr)
+        pstr = os.path.join(base, u"profiles", prof)
+        if os.path.exists(pstr):
+            profiler.Profile().Load(pstr)
+            profiler.Profile().Update()
+            profiler.UpdateProfileLoader()
+
+        if not err:
+            wx.MessageBox(_("Your profile has been updated to the latest "
+                "version") + u"\n" + \
+              _("Please check the preferences dialog to check "
+                "your preferences"),
+              _("Profile Updated"))
+
+    return not err
+
+#--------------------------------------------------------------------------#
+
+def TranslateEOLMode():
+    """Translate old eol mode persistance to new one
+    @prerequisite: Profile has been initialized / loaded
+
+    """
+    eol_m = profiler.Profile_Get('EOL')
+    if len(eol_m) > 4:
+        emap = { 'm' : 'CR', 'w' : 'CRLF', 'u' : 'LF' }
+        cmode = eol_m[0].lower()
+        profiler.Profile_Set('EOL', emap.get(cmode, 'LF'))
+
+#--------------------------------------------------------------------------#
+
 def PrintHelp():
     """Print command line help
     @postcondition: Help is printed and program exits
@@ -745,9 +850,6 @@ def Main():
     """
     opts, args = ProcessCommandLine()
 
-    # We are ready to run so fire up the config and launch the app
-    profile_updated = InitConfig()
-
     # Put extern subpackage on path so that bundled external dependancies
     # can be found if needed.
     if not hasattr(sys, 'frozen'):
@@ -773,7 +875,7 @@ def Main():
         editra_app.Destroy()
         os._exit(0)
 
-    if profile_updated:
+    if editra_app.GetProfileUpdated():
         # Make sure window iniliazes to default position
         profiler.Profile_Del('WPOS')
         wx.MessageBox(_("Your profile has been updated to the latest "
