@@ -8,22 +8,20 @@
 ###############################################################################
 
 """
-FILE: autocomp.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
-SUMMARY:
-   Provides an interface/service for getting autocompletion/calltip data
+Provides an interface/service for getting autocompletion/calltip data
 into an stc control. This is a data provider only it does not do provide
 any UI functionality or calls. The user called object from this library
 is intended to be the AutoCompService. This service provides the generic
 interface into the various language specific autocomplete services, and
 makes the calls to the other support objects/functions in this library.
 
+@summary: Autocompletion support interface implementation
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: autocomp.py 51603 2008-02-08 14:06:25Z CJP $"
-__revision__ = "$Revision: 51603 $"
+__cvsid__ = "$Id: autocomp.py 56691 2008-11-06 19:26:42Z CJP $"
+__revision__ = "$Revision: 56691 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -57,6 +55,9 @@ class AutoCompService(object):
             return self._completer.GetAutoCompKeys()
         else:
             return list()
+        
+    def IsAutoCompEvent(self, evt):
+        return self._completer.IsAutoCompEvent(evt) if self._completer else False
 
     def GetAutoCompList(self, command):
         """Retrieves the sorted autocomplete list for a command
@@ -78,6 +79,9 @@ class AutoCompService(object):
             return self._completer.GetAutoCompStops()
         else:
             return u''
+        
+    def GetAutoCompFillups(self):
+        return self._completer.GetAutoCompFillups() if self._completer else u''
 
     def GetCallTip(self, command):
         """Returns the calltip string for a command
@@ -98,6 +102,9 @@ class AutoCompService(object):
             return self._completer.GetCallTipKeys()
         else:
             return list()
+        
+    def IsCallTipEvent(self, evt):
+        return self._completer.IsCallTipEvent(evt) if self._completer else False
 
     def GetIgnoreCase(self):
         """Are commands case sensitive or not
