@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 56611 2008-10-31 03:43:03Z CJP $"
-__revision__ = "$Revision: 56611 $"
+__svnid__ = "$Id: ed_main.py 56950 2008-11-24 01:25:08Z CJP $"
+__revision__ = "$Revision: 56950 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -160,6 +160,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_PRINT_SU, self.OnPrint),
 
                                        # Edit Menu
+                                       (ID_PASTE_AFTER, self.DispatchToControl),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -201,6 +202,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_COPY, self.OnUpdateClipboardUI),
                                      (ID_CUT, self.OnUpdateClipboardUI),
                                      (ID_PASTE, self.OnUpdateClipboardUI),
+                                     (ID_PASTE_AFTER, self.OnUpdateClipboardUI),
                                      (ID_UNDO, self.OnUpdateClipboardUI),
                                      (ID_REDO, self.OnUpdateClipboardUI),
                                      # Format Menu
@@ -504,6 +506,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wxMenuEvent
 
         """
+        if not self.IsActive():
+            evt.Skip()
+            return
+
         e_id = evt.GetId()
         if e_id == ID_CLOSE:
             self.nb.ClosePage()
@@ -703,8 +709,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 self.Close(True) # Force exit since there is a problem
 
             self.LOG("[ed_main][evt] OnClose: Requesting Page Close")
-            result = self.nb.ClosePage()
-            if result == wx.ID_CANCEL:
+            if not self.nb.ClosePage():
                 self._exiting = False
                 ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED,
                                    (self.nb, self.nb.GetSelection()))
@@ -908,7 +913,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                         ID_JOIN_LINES, ID_CUT_LINE, ID_COPY_LINE, ID_INDENT,
                         ID_UNINDENT, ID_TRANSPOSE, ID_COMMENT, ID_UNCOMMENT,
                         ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
-                        ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE ]
+                        ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
+                        ID_PASTE_AFTER ]
 
         has_focus = self.FindFocus()
         if has_focus != ctrl and e_id in active_only:
@@ -1006,15 +1012,33 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
+        focus = self.FindFocus()
         ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_UNDO:
-            evt.Enable(ctrl.CanUndo())
+            can_undo = False
+            if hasattr(focus, 'CanUndo'):
+                can_undo = focus.CanUndo()
+            evt.Enable(can_undo)
         elif e_id == ID_REDO:
-            evt.Enable(ctrl.CanRedo())
-        elif e_id == ID_PASTE:
-            evt.Enable(ctrl.CanPaste())
-        elif e_id in [ID_COPY, ID_CUT]:
-            evt.Enable(ctrl.GetSelectionStart() != ctrl.GetSelectionEnd())
+            can_redo = False
+            if hasattr(focus, 'CanRedo'):
+                can_redo = focus.CanRedo()
+            evt.Enable(can_redo)
+        elif e_id in (ID_PASTE, ID_PASTE_AFTER):
+            can_paste = False
+            if hasattr(focus, 'CanPaste'):
+                can_paste = focus.CanPaste()
+            evt.Enable(can_paste)
+        elif e_id == ID_COPY:
+            can_copy = False
+            if hasattr(focus, 'CanCopy'):
+                can_copy = focus.CanCopy()
+            evt.Enable(can_copy)
+        elif e_id == ID_CUT:
+            can_cut = False
+            if hasattr(focus, 'CanCut'):
+                can_cut = focus.CanCut()
+            evt.Enable(can_cut)
         else:
             evt.Skip()
 
