@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 56649 2008-11-02 17:19:34Z CJP $"
-__revision__ = "$Revision: 56649 $"
+__svnid__ = "$Id: ed_menu.py 56853 2008-11-19 20:23:26Z CJP $"
+__revision__ = "$Revision: 56853 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -549,6 +549,9 @@ class EdMenuBar(wx.MenuBar):
         editmenu.Append(ed_glob.ID_PASTE, _("&Paste") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_PASTE),
                         _("Paste Text from Clipboard to File"))
+        editmenu.Append(ed_glob.ID_PASTE_AFTER, _("P&aste After") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_PASTE_AFTER),
+                        _("Paste Text from Clipboard to File after the cursor"))
         editmenu.AppendSeparator()
         editmenu.Append(ed_glob.ID_SELECTALL, _("Select &All") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_SELECTALL),
@@ -738,18 +741,18 @@ class EdMenuBar(wx.MenuBar):
 
         # Line EOL formatting submenu
         lineformat = self._menus['lineformat'] = EdMenu()
-        lineformat.Append(ed_glob.ID_EOL_MAC, _("Macintosh (\\r)") + \
+        lineformat.Append(ed_glob.ID_EOL_MAC, _("Old Macintosh (\\r)") + \
                           EdMenuBar.keybinder.GetBinding(ed_glob.ID_EOL_MAC),
                           _("Format all EOL characters to %s Mode") % \
-                          u"Macintosh (\\r)", wx.ITEM_CHECK)
+                          _(u"Old Macintosh (\\r)"), wx.ITEM_CHECK)
         lineformat.Append(ed_glob.ID_EOL_UNIX, _("Unix (\\n)") + \
                           EdMenuBar.keybinder.GetBinding(ed_glob.ID_EOL_UNIX),
                           _("Format all EOL characters to %s Mode") % \
-                          u"Unix (\\n)", wx.ITEM_CHECK)
+                          _(u"Unix (\\n)"), wx.ITEM_CHECK)
         lineformat.Append(ed_glob.ID_EOL_WIN, _("Windows (\\r\\n)") + \
                           EdMenuBar.keybinder.GetBinding(ed_glob.ID_EOL_WIN),
                           _("Format all EOL characters to %s Mode") % \
-                          "Windows (\\r\\n)", wx.ITEM_CHECK)
+                          _("Windows (\\r\\n)"), wx.ITEM_CHECK)
         formatmenu.AppendMenu(ed_glob.ID_EOL_MODE, _("EOL Mode"), lineformat,
                               _("End of line character formatting"))
 
@@ -975,6 +978,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_CUT : ("Ctrl", "X"),
                      ed_glob.ID_COPY : ("Ctrl", "C"),
                      ed_glob.ID_PASTE : ("Ctrl", "V"),
+                     ed_glob.ID_PASTE_AFTER : ("Ctrl", "Shift", "V"),
                      ed_glob.ID_SELECTALL : ("Ctrl", "A"),
                      ed_glob.ID_LINE_AFTER : ("Ctrl", "L"),
                      ed_glob.ID_LINE_BEFORE : ("Ctrl", "Shift", "L"),
