@@ -20,14 +20,17 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 54987 2008-08-05 23:18:42Z CJP $"
-__revision__ = "$Revision: 54987 $"
+__svnid__ = "$Id: ed_style.py 56813 2008-11-17 04:44:05Z CJP $"
+__revision__ = "$Revision: 56813 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import re
 import wx
+
+# Editra Libraries
+import ed_glob
 import util
 from profiler import Profile_Get, Profile_Set
 
@@ -242,6 +245,8 @@ class StyleItem(object):
 
         """
         self.null = False
+        if back is None:
+            back = u''
         self.back = back
         if ex and ex not in self._exattr:
             self._exattr.append(ex)
@@ -252,6 +257,9 @@ class StyleItem(object):
         @keyword ex: extra attribute (i.e bold, italic, underline)
 
         """
+        self.null = False
+        if face is None:
+            face = u''
         self.face = face
         if ex and ex not in self._exattr:
             self._exattr.append(ex)
@@ -263,6 +271,8 @@ class StyleItem(object):
 
         """
         self.null = False
+        if fore is None:
+            fore = u''
         self.fore = fore
         if ex and ex not in self._exattr:
             self._exattr.append(ex)
@@ -275,6 +285,8 @@ class StyleItem(object):
 
         """
         self.null = False
+        if size is None:
+            size = u''
         self.size = str(size)
         if ex and ex not in self._exattr:
             self._exattr.append(ex)
@@ -306,10 +318,13 @@ class StyleItem(object):
         @note: This is not intended to be used for setting extra
                attributes such as bold, eol, ect..
         @param attr: a particular attribute to set (i.e fore, face, back, size)
-        @param value: value to set the attribute to contain
+        @param value: value to set the attribute to contain. None to clear the
+                      value.
 
         """
         self.null = False
+        if value is None:
+            value = u''
         cur_val = getattr(self, attr, None)
         if cur_val is not None:
             if u"," in value:
@@ -344,6 +359,7 @@ class StyleMgr(object):
         # Attributes
         self.fonts = self.GetFontDictionary()
         self.style_set = custom
+        self.syntax_set = list()
         self.LOG = wx.GetApp().GetLog()
 
         # Get the Style Set
@@ -370,6 +386,27 @@ class StyleMgr(object):
                                           "%(primary)s", "%(size)d")
         return sty_dict
 
+    def FindTagById(self, style_id):
+        """Find the style tag that is associated with the given
+        Id. If not found it returns an empty string.
+        @param style_id: id of tag to look for
+        @return: style tag string
+        @todo: change syntax modules to all use ids
+
+        """
+        for data in self.syntax_set:
+            # If its a standard lexer the style id will be stored as
+            # a string. If its a container lexer it is the id.
+            if isinstance(data[0], basestring):
+                s_id = getattr(wx.stc, data[0])
+            else:
+                s_id = data[0]
+
+            if style_id == s_id:
+                return data[1]
+
+        return 'default_style'
+
     def GetFontDictionary(self, default=True):
         """Does a system lookup to build a default set of fonts using
         ten point fonts as the standard size.
@@ -526,6 +563,47 @@ class StyleMgr(object):
         """
         return StyleMgr.STYLES.get(self.style_set, DefaultStyleDictionary())
 
+    @staticmethod
+    def GetStyleSheet(sheet_name=None):
+        """Finds the current style sheet and returns its path. The
+        Lookup is done by first looking in the users config directory
+        and if it is not found there it looks for one on the system
+        level and if that fails it returns None.
+        @param sheet_name: style sheet to look for
+        @return: full path to style sheet
+
+        """
+        if sheet_name:
+            style = sheet_name
+            if sheet_name.split(u'.')[-1] != u"ess":
+                style += u".ess"
+        elif Profile_Get('SYNTHEME', 'str').split(u'.')[-1] != u"ess":
+            style = (Profile_Get('SYNTHEME', 'str') + u".ess").lower()
+        else:
+            style = Profile_Get('SYNTHEME', 'str').lower()
+
+        # Get Correct Filename if it exists
+        for sheet in util.GetResourceFiles('styles', False, True, title=False):
+            if sheet.lower() == style.lower():
+                style = sheet
+                break
+
+        user = os.path.join(ed_glob.CONFIG['STYLES_DIR'], style)
+        sysp = os.path.join(ed_glob.CONFIG['SYS_STYLES_DIR'], style)
+        if os.path.exists(user):
+            return user
+        elif os.path.exists(sysp):
+            return sysp
+        else:
+            return None
+
+    def GetSyntaxParams(self):
+        """Get the set of syntax parameters
+        @return: list
+
+        """
+        return self.syntax_set
+
     def HasNamedStyle(self, name):
         """Checks if a style has been set/loaded or not
         @param name: tag name of style to look for
@@ -683,7 +761,8 @@ class StyleMgr(object):
 
                     v1ok = v2ok = False
                     # Check that colors are a hex string
-                    if attrib[0] in "fore back" and RE_HEX_STR.match(values[0]):
+                    if len(values) and \
+                       attrib[0] in "fore back" and RE_HEX_STR.match(values[0]):
                         v1ok = True
                     elif len(values) and attrib[0] == "size":
                         if RE_ESS_SCALAR.match(values[0]) or values[0].isdigit():
@@ -827,6 +906,98 @@ class StyleMgr(object):
                      "dictionary of StyleItems")
             return False
 
+    def SetSyntax(self, syn_lst):
+        """Sets the Syntax Style Specs from a list of specifications
+        @param syn_lst: [(STYLE_ID, "STYLE_TYPE"), (STYLE_ID2, "STYLE_TYPE2)]
+
+        """
+        # Parses Syntax Specifications list, ignoring all bad values
+        self.UpdateBaseStyles()
+        valid_settings = list()
+        for syn in syn_lst:
+            if len(syn) != 2:
+                continue
+            else:
+                if self.GetLexer() == wx.stc.STC_LEX_CONTAINER:
+                    self.StyleSetSpec(syn[0], self.GetStyleByName(syn[1]))
+                else:
+                    if not isinstance(syn[0], basestring) or \
+                       not hasattr(wx.stc, syn[0]):
+                        continue
+                    elif not isinstance(syn[1], basestring):
+                        continue
+                    else:
+                        self.StyleSetSpec(getattr(wx.stc, syn[0]), \
+                                          self.GetStyleByName(syn[1]))
+                valid_settings.append(syn)
+
+        self.syntax_set = valid_settings
+        return True
+
+    def StyleDefault(self):
+        """Clears the editor styles to default
+        @postcondition: style is reset to default
+
+        """
+        self.StyleClearAll()
+        self.SetCaretForeground(wx.NamedColor("black"))
+        self.Colourise(0, -1)
+
+    def UpdateAllStyles(self, spec_style=None):
+        """Refreshes all the styles and attributes of the control
+        @param spec_style: style scheme name
+        @postcondition: style scheme is set to specified style
+
+        """
+        if spec_style != self.style_set:
+            self.LoadStyleSheet(self.GetStyleSheet(spec_style), force=True)
+        self.UpdateBaseStyles()
+        self.SetSyntax(self.GetSyntaxParams())
+        self.Refresh()
+
+    def UpdateBaseStyles(self):
+        """Updates the base styles of editor to the current settings
+        @postcondition: base style info is updated
+
+        """
+        self.StyleDefault()
+        self.SetMargins(4, 0)
+        # Global default styles for all languages
+        self.StyleSetSpec(0, self.GetStyleByName('default_style'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_DEFAULT, \
+                          self.GetStyleByName('default_style'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_LINENUMBER, \
+                          self.GetStyleByName('line_num'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_CONTROLCHAR, \
+                          self.GetStyleByName('ctrl_char'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_BRACELIGHT, \
+                          self.GetStyleByName('brace_good'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_BRACEBAD, \
+                          self.GetStyleByName('brace_bad'))
+        self.StyleSetSpec(wx.stc.STC_STYLE_INDENTGUIDE, \
+                          self.GetStyleByName('guide_style'))
+
+        # wx.stc.STC_STYLE_CALLTIP doesnt seem to do anything
+        calltip = self.GetItemByName('calltip')
+        self.CallTipSetBackground(calltip.GetBack())
+        self.CallTipSetForeground(calltip.GetFore())
+
+        sback = self.GetItemByName('select_style')
+        if not sback.IsNull():
+            sback = sback.GetBack()
+        else:
+            sback = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+        self.SetSelBackground(True, sback)
+
+        wspace = self.GetItemByName('whitespace_style')
+        if not wspace.IsNull():
+            self.SetWhitespaceBackground(True, wspace.GetBack())
+            self.SetWhitespaceForeground(True, wspace.GetFore())
+
+        self.SetCaretForeground(self.GetDefaultForeColour())
+        self.SetCaretLineBack(self.GetItemByName('caret_line').GetBack())
+        self.Colourise(0, -1)
+
 #-----------------------------------------------------------------------------#
 # Utility Functions
 def DefaultStyleDictionary():
