@@ -12,11 +12,11 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 55014 2008-08-07 19:39:33Z CJP $"
-__revision__ = "$Revision: 55014 $"
+__svnid__ = "$Id: ed_txt.py 56950 2008-11-24 01:25:08Z CJP $"
+__revision__ = "$Revision: 56950 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import os
 import sys
 import re
@@ -25,32 +25,28 @@ import locale
 import types
 from StringIO import StringIO
 
-# Local Editra Libs
-from util import Log
+# Local Imports
+from util import Log, GetFileModTime
+from profiler import Profile_Get
 
 #--------------------------------------------------------------------------#
 # Globals
 
-# Default encoding to use when nothing is specified
-# Use utf-8 where available else fallback to the system
-# encoding
+# The default fallback encoding
 DEFAULT_ENCODING = locale.getpreferredencoding()
 try:
     codecs.lookup(DEFAULT_ENCODING)
-except LookupError:
+except (LookupError, TypeError):
     DEFAULT_ENCODING = 'utf-8'
 
 # File Helper Functions
 BOM = { 'utf-8' : codecs.BOM_UTF8,
         'utf-16' : codecs.BOM }
 
-#ENC = [ 'utf-8', 'utf-16', 'latin-1', 'ascii' ]
-#        'utf-32-be', 'utf-32-le', 
-
 # Regex for extracting magic comments from source files
 # i.e *-* coding: utf-8 *-*, encoding=utf-8, ect...
 # The first group from this expression will be the encoding.
-RE_MAGIC_COMMENT = re.compile("coding[:=]\s*([-\w.]+)")
+RE_MAGIC_COMMENT = re.compile("coding[:=]\s*\"*([-\w.]+)\"*")
 
 #--------------------------------------------------------------------------#
 
@@ -79,12 +75,20 @@ class EdFile(object):
         # Attribtues
         self._handle = None
         self._magic = dict(comment=None, bad=False)
-        self.encoding = DEFAULT_ENCODING
+        self.encoding = Profile_Get('ENCODING', default=DEFAULT_ENCODING)
         self.open = False
         self.path = path
         self.bom = None
         self.modtime = modtime
         self.last_err = None
+        self._mcallback = list()
+
+    def AddModifiedCallback(self, callback):
+        """Set modified callback method
+        @param callback: callable
+
+        """
+        self._mcallback.append(callback)
 
     def ClearLastError(self):
         """Reset the error marker on this file"""
@@ -128,6 +132,21 @@ class EdFile(object):
         """File encoding property"""
         return self.encoding
 
+    def FireModified(self):
+        """Fire the modified callback(s)"""
+        remove = list()
+        for idx, mcallback in enumerate(self._mcallback):
+            try:
+                mcallback()
+            except:
+                remove.append(idx)
+
+        # Cleanup any bad callbacks
+        if len(remove):
+            remove.reverse()
+            for idx in remove:
+                list.pop(idx)
+
     def GetEncoding(self):
         """Get the encoding used by the file it may not be the
         same as the encoding requested at construction time
@@ -236,15 +255,24 @@ class EdFile(object):
                 txt = txt.replace(self.bom, u'', 1)
 
             Log("[ed_txt][info] Decoded %s with %s" % (self.path, self.encoding))
+            self.SetModTime(GetFileModTime(self.path))
             return txt
         else:
             raise ReadError, self.last_err
 
+    def RemoveModifiedCallback(self, callback):
+        """Remove a registered callback
+        @param callback: callable to remove
+
+        """
+        if callback in self._mcallback:
+            self._mcallback.remove(callback)
+
     def ResetAll(self):
         """Reset all attributes of this file"""
         self._handle = None
         self._magic = dict(comment=None, bad=False)
-        self.encoding = DEFAULT_ENCODING
+        self.encoding = Profile_Get('ENCODING', default=DEFAULT_ENCODING)
         self.open = False
         self.path = ''
         self.bom = None
@@ -256,6 +284,8 @@ class EdFile(object):
         @param enc: encoding to change to
 
         """
+        if enc is None:
+            enc = DEFAULT_ENCODING
         self.encoding = enc
 
     def SetPath(self, path):
@@ -265,7 +295,7 @@ class EdFile(object):
         """
         self.path = path
 
-    def SetModtime(self, mtime):
+    def SetModTime(self, mtime):
         """Set the modtime of this file
         @param mtime: long int to set modtime to
 
@@ -352,7 +382,7 @@ def DecodeString(string, encoding=None):
     @keyword encoding: encoding to decode string with
 
     """
-    if not encoding:
+    if encoding is None:
         encoding = DEFAULT_ENCODING
 
     if not isinstance(string, types.UnicodeType):
@@ -415,6 +445,8 @@ def GetEncodings():
 
     """
     encodings = list()
+    encodings.append(Profile_Get('ENCODING', None))
+
     try:
         encodings.append(locale.getpreferredencoding())
     except:
