@@ -13,8 +13,8 @@ perspectives in the MainWindow.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: perspective.py 52855 2008-03-27 14:53:06Z CJP $"
-__revision__ = "$Revision: 52855 $"
+__cvsid__ = "$Id: perspective.py 56854 2008-11-19 21:22:29Z CJP $"
+__revision__ = "$Revision: 56854 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -79,7 +79,8 @@ class PerspectiveManager(object):
 
         # Restore the managed windows previous position and alpha
         # preferences if they are available.
-        self._window.SetTransparent(Profile_Get('ALPHA', default=255))
+        level = max(100, Profile_Get('ALPHA', default=255))
+        self._window.SetTransparent(level)
         pos = Profile_Get('WPOS', "size_tuple", False)
         if Profile_Get('SET_WPOS') and pos:
             # Ensure window is on screen
@@ -258,8 +259,6 @@ class PerspectiveManager(object):
         e_id = evt.GetId()
         if e_id in self._ids + [ID_AUTO_PERSPECTIVE]:
             evt.Check(self._menu.GetLabel(e_id) == self._currview)
-            evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-            evt.SetUpdateInterval(500)
         else:
             evt.Skip()
 
