@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 56361 2008-10-16 15:41:15Z CJP $"
-__revision__ = "$Revision: 56361 $"
+__svnid__ = "$Id: profiler.py 56855 2008-11-19 21:23:23Z CJP $"
+__revision__ = "$Revision: 56855 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -39,7 +39,7 @@ _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
 # Globals
 _DEFAULTS = {
-           'ALPHA'      : 255,              # Transparency level
+           'ALPHA'      : 255,              # Transparency level (0-255)
            'AALIASING'  : False,            # Use Anti-Aliasing if availble
            'APPSPLASH'  : True,             # Show splash at startup
            'AUTO_COMP'  : True,             # Use Auto-comp if available
@@ -55,7 +55,7 @@ _DEFAULTS = {
            'DEFAULT_VIEW' : 'Automatic',    # Default Perspective
            'EDGE'       : 80,               # Edge guide column
            'ENCODING'   : None,             # Prefered text encoding
-           'EOL'        : 'Unix (\\n)',     # EOL mode
+           'EOL'        : 'LF',             # EOL mode
            'FHIST'      : list(),           # List of history files
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
            'FFILTER'    : 0,                # Last file filter used
@@ -225,10 +225,10 @@ class Profile(dict):
         """
         try:
             self.Set('MYPROFILE', path)
+            UpdateProfileLoader()
             fhandle = open(path, 'wb')
             cPickle.dump(self.copy(), fhandle, cPickle.HIGHEST_PROTOCOL)
             fhandle.close()
-            UpdateProfileLoader()
         except (IOError, cPickle.PickleError), msg:
             dev_tool.DEBUGP("[profile][err] %s" % str(msg))
             return False
@@ -348,13 +348,14 @@ def AddFileHistoryToProfile(file_history):
 
 def CalcVersionValue(ver_str="0.0.0"):
     """Calculates a version value from the provided dot-formated string
-    @keyword ver_str: Version string to calculate value of
 
     1) SPECIFICATION: Version value calculation AA.BBB.CCC
          - major values: < 1     (i.e 0.0.85 = 0.850)
          - minor values: 1 - 999 (i.e 0.1.85 = 1.850)
          - micro values: >= 1000 (i.e 1.1.85 = 1001.850)
 
+    @keyword ver_str: Version string to calculate value of
+
     """
     ver_str = ''.join([char for char in ver_str
                        if char.isdigit() or char == '.'])
@@ -378,10 +379,9 @@ def GetLoader():
     """
     cbase = CONFIG['CONFIG_BASE']
     if cbase is None:
-        loader = os.path.join(wx.GetHomeDir(), u"." + PROG_NAME,
-                              u"profiles", u".loader2")
-    else:
-        loader = os.path.join(cbase, u"profiles", u".loader2")
+        cbase = wx.StandardPaths_Get().GetUserDataDir()
+
+    loader = os.path.join(cbase, u"profiles", u".loader2")
 
     return loader
 
@@ -420,7 +420,7 @@ def ProfileVersionStr():
 
     """
     loader = GetLoader()
-    reader = util.GetFileReader(loader)
+    reader = util.GetFileReader(loader, sys.getfilesystemencoding())
     if reader == -1:
         return "0.0.0"
 
@@ -455,7 +455,11 @@ def UpdateProfileLoader():
     if not prof_name:
         prof_name = CONFIG['PROFILE_DIR'] + 'default.ppb'
 
-    prof_name = prof_name.encode(sys.getfilesystemencoding())
+    if not os.path.exists(prof_name):
+        prof_name = os.path.join(CONFIG['CONFIG_DIR'],
+                                 os.path.basename(prof_name))
+        Profile_Set('MYPROFILE', prof_name)
+
     writer.write(prof_name)
     writer.write(u"\nVERSION\t" + VERSION)
     writer.close()
