@@ -19,8 +19,8 @@ LANGUAGE: Python
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 55738 2008-09-19 16:40:49Z CJP $"
-__revision__ = "$Revision: 55738 $"
+__svnid__ = "$Id: synextreg.py 56840 2008-11-18 19:32:54Z CJP $"
+__revision__ = "$Revision: 56840 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -236,6 +236,10 @@ LANG_LATEX = u'LaTeX'
 ID_LANG_VB = _NewId()
 LANG_VB = u'Visual Basic'
 
+# Use LEX_VBSCRIPT
+ID_LANG_VBSCRIPT = _NewId()
+LANG_VBSCRIPT = u'VBScript'
+
 # Use LEX_VERILOG
 ID_LANG_VERILOG = _NewId()
 LANG_VERILOG = u'Verilog'
@@ -347,6 +351,7 @@ EXT_MAP = {
            'txt'                : LANG_TXT,
            'vala'               : LANG_VALA,
            'bas cls ctl frm vb' : LANG_VB,
+           'vbs dsm'            : LANG_VBSCRIPT,
            'v'                  : LANG_VERILOG,
            'vh vhdl'            : LANG_VHDL,
            'axl dtd plist rdf svg xml xrc xsd xsl xslt xul' : LANG_XML,
